@@ -9,7 +9,7 @@
        prof.out <- c()
        functionsgood <- functions
        rownames(functionsgood) = 1:n
-       functionsgood2 = fts(1:dim(functionsgood)[2],t(functionsgood))
+       functionsgood2 = fts(1:dim(functionsgood)[2], t(functionsgood))
        while(hay == 1){
              d = dfunc(functionsgood2, trim = trim, ...)$prof
              if(is.null(outliers)){
@@ -18,15 +18,14 @@
              fecha <- as.numeric(rownames(functionsgood)[d < cutoff])
              elim <- which(d < cutoff)
              if(length(elim) > 0){
-                prof.out <- c(prof.out,d[d<cutoff])
-                functionsgood <- functionsgood[-elim,]
-                outliers <- c(outliers,fecha)
+                prof.out <- c(prof.out, d[d<cutoff])
+                functionsgood <- functionsgood[-elim, ]
+                outliers <- c(outliers, fecha)
              }
-             if(length(elim) == 0||length(outliers) > n/5){
+             if(length(elim) == 0||length(outliers) > n / 5){
                 hay <- 0
              }                    
        }
-       return(list("outliers" = outliers,"cutoff" = cutoff,"depth.total" = dtotal,
-              "depth.out" = prof.out))
+       return(list("outliers" = outliers, "cutoff" = cutoff, "depth.total" = dtotal, "depth.out" = prof.out))
 }
 
